- Add `xoutil.bound.until`:func: and `xoutil.bound.until_errors`:func:.

- Fix issue that made `xoutil.uuid`:mod: unusable.  Introduced in
  version 1.7.1, commit `58eb359
  <https://github.com/merchise-autrement/xoutil/commit/58eb35950cc33a9ecaa6565895e1b2147cace9f9_>`__.

- Remove support for Python 3.1 and Python 3.2.
